==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Верх</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Низ</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Левая</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Назад влево</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Правая</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Назад вправо</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Повернуть выделение против часовой стрелки до проекции</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Повернуть выделение по часовой стрелке до проекции</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Масштабировать проекцию к исходному размеру (&apos;изометрической рисунок&apos;)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Истинная шкала</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Изометрическая проекция</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Верх</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Низ</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Левая</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Назад влево</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Правая</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Назад вправо</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Повернуть выделение против часовой стрелки до проекции</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Повернуть выделение по часовой стрелке до проекции</translation>
    </message>
    <message>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation type="vanished">Масштабировать проекцию к исходному размеру (&apos;изометрической рисунок&apos;)</translation>
    </message>
    <message>
        <source>True scale</source>
        <translation type="vanished">Истинная шкала</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Изометрическая проекция</translation>
    </message>
    <message>
        <location filename="../IsoProject.js" line="+50"/>
        <source>Isometric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Isometric True Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Planometric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimetric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cabinet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cavalier</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
